==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/pl/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'Potwierdź zbiorcze usuwanie aktywów',
  'bulk_delete_help'	=> 'Przejrzyj usuwanie zbiorcze aktywów poniżej. Po usunięciu tych aktywów będą one mogły zostać przywrócone, ale nie będą one skojarzone z żadnym z użytkowników, do których są aktualnie przypisane.',
  'bulk_delete_warn'	=> 'Zamierzasz usunąć :asset_count aktywów.',
	'bulk_update'		=> 'Zbiorcza aktualizacja aktywów',
	'bulk_update_help'	=> 'Ten formularz umożliwia zbiorczą aktualizację wielu aktywów na raz. Wypełnij tylko te pola, które chcesz zmienić. Puste pola pozostaną niezmienione. ',
	'bulk_update_warn'	=> 'Zamierzasz edytować właściwości :asset_count zestawów.',
    'checkedout_to'		=> 'Wypożyczony do',
    'checkout_date'		=> 'Data przypisania',
    'checkin_date'		=> 'Data przypisania',
    'checkout_to'		=> 'Przypisane do',
    'cost'				=> 'Koszt zakupu',
    'create'			=> 'Nowy nabytek',
    'date'				=> 'Data zakupu',
    'depreciation'	    => 'Deprecjacja',
    'depreciates_on'	=> 'Amortyzacja włączona',
    'default_location'	=> 'Domyślna lokalizacja',
    'eol_date'			=> 'Data końca licencji',
    'eol_rate'			=> 'Szacowany koniec licencji',
    'expected_checkin'  => 'Przewidywana data przyjęcia',
    'expires'			=> 'Wygasa',
    'fully_depreciated'	=> 'W pełni zamortyzowany',
    'help_checkout'		=> 'Jeśli chcesz natychmiast przypisać ten zasób, wybierz "Gotowy do wdrożęnia" z powyższej listy stanu. ',
    'mac_address'		=> 'Adres MAC',
    'manufacturer'		=> 'Producent',
    'model'				=> 'Model',
    'months'			=> 'miesiąc',
    'name'				=> 'Nazwa nabytku',
    'notes'				=> 'Notatki',
    'order'				=> 'Numer zamówienia',
    'qr'				=> 'Kod QR',
    'requestable'		=> 'Użytkownicy mogą wymagać tego zasobu',
    'select_statustype'	=> 'Wybierz status',
    'serial'			=> 'Numer seryjny',
    'status'			=> 'Status',
    'tag'				=> 'Tag-i zasobu/nabytku',
    'update'			=> 'Aktualizacja zasobu/nabytku',
    'warranty'			=> 'Gwarancja',
		'warranty_expires'		=> 'Gwarancja wygasa',
    'years'				=> 'rok',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/pl/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Potwierdź zbiorcze usuwanie aktywów',
  'bulk_delete_help'	=> 'Przejrzyj usuwanie zbiorcze aktywów poniżej. Po usunięciu tych aktywów będą one mogły zostać przywrócone, ale nie będą one skojarzone z żadnym z użytkowników, do których są aktualnie przypisane.',
  'bulk_delete_warn'	=> 'Zamierzasz usunąć :asset_count aktywów.',
    'bulk_update'		=> 'Zbiorcza aktualizacja aktywów',
    'bulk_update_help'	=> 'Ten formularz umożliwia zbiorczą aktualizację wielu aktywów na raz. Wypełnij tylko te pola, które chcesz zmienić. Puste pola pozostaną niezmienione. ',
    'bulk_update_warn'	=> 'Zamierzasz edytować właściwości :asset_count zestawów.',
    'checkedout_to'		=> 'Wypożyczony do',
    'checkout_date'		=> 'Data przypisania',
    'checkin_date'		=> 'Data przypisania',
    'checkout_to'		=> 'Przypisane do',
    'cost'				=> 'Koszt zakupu',
    'create'			=> 'Nowy nabytek',
    'date'				=> 'Data zakupu',
    'depreciation'	    => 'Deprecjacja',
    'depreciates_on'	=> 'Amortyzacja włączona',
    'default_location'	=> 'Domyślna lokalizacja',
    'eol_date'			=> 'Data końca licencji',
    'eol_rate'			=> 'Szacowany koniec licencji',
    'expected_checkin'  => 'Przewidywana data przyjęcia',
    'expires'			=> 'Wygasa',
    'fully_depreciated'	=> 'W pełni zamortyzowany',
    'help_checkout'		=> 'Jeśli chcesz natychmiast przypisać ten zasób, wybierz "Gotowy do wdrożęnia" z powyższej listy stanu. ',
    'mac_address'		=> 'Adres MAC',
    'manufacturer'		=> 'Producent',
    'model'				=> 'Model',
    'months'			=> 'miesiąc',
    'name'				=> 'Nazwa nabytku',
    'notes'				=> 'Notatki',
    'order'				=> 'Numer zamówienia',
    'qr'				=> 'Kod QR',
    'requestable'		=> 'Użytkownicy mogą wymagać tego zasobu',
    'select_statustype'	=> 'Wybierz status',
    'serial'			=> 'Numer seryjny',
    'status'			=> 'Status',
    'tag'				=> 'Tag-i zasobu/nabytku',
    'update'			=> 'Aktualizacja zasobu/nabytku',
    'warranty'			=> 'Gwarancja',
        'warranty_expires'		=> 'Gwarancja wygasa',
    'years'				=> 'rok',
    'asset_location' => 'Zaktualizuj lokalizację aktywa',
    'asset_location_update_default_current' => 'Zaktualizuj domyślną i aktualną lokalizację',
    'asset_location_update_default' => 'Zaktualizuj tylko domyślną lokalizację',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Przetwarzanie...',
];
